toplev.c, [...]: Change comments mentioning C9X to refer to C99 instead.
authorJoseph Myers <jsm28@cam.ac.uk>
Sun, 29 Oct 2000 19:34:53 +0000 (19:34 +0000)
committerJoseph Myers <jsm28@gcc.gnu.org>
Sun, 29 Oct 2000 19:34:53 +0000 (19:34 +0000)
* toplev.c, flags.h, fold-const.c, real.c, rtl.c,
fixinc/inclhack.def: Change comments mentioning C9X to refer to
C99 instead.

From-SVN: r37127

gcc/ChangeLog
gcc/fixinc/inclhack.def
gcc/flags.h
gcc/fold-const.c
gcc/real.c
gcc/rtl.c
gcc/toplev.c

index 0f12f3c9189b269355d42b15dd0d3bfe52dd3916..8bcfe30b010b250505602f54e3bbaf75217bc4a9 100644 (file)
@@ -1,5 +1,9 @@
 2000-10-29  Joseph S. Myers  <jsm28@cam.ac.uk>
 
+       * toplev.c, flags.h, fold-const.c, real.c, rtl.c,
+       fixinc/inclhack.def: Change comments mentioning C9X to refer to
+       C99 instead.
+
        * invoke.texi: Document that -V will only work for very similar
        versions of driver and compiler.
 
index b46121623ef164bd1f92e273813a5c8aed608a63..5688c6e8a6d0880edc68540ba71cc06a6faaabb6 100644 (file)
@@ -876,7 +876,7 @@ fix = {
 
 /*
  *  Remove `extern double cabs' declarations from math.h.
- *  This conflicts with C9x.  Discovered on AIX.
+ *  This conflicts with C99.  Discovered on AIX.
  *  SunOS4 has its cabs() declaration followed by a comment which
  *  terminates on the following line.
  */
index dec686dfe38f8da36a474e3720d86ee60fee8df2..bc686e46e1a02d45efcfbbcbc035027a402dca9b 100644 (file)
@@ -337,7 +337,7 @@ extern int flag_errno_math;
 
 /* 0 means straightforward implementation of complex divide acceptable.
    1 means wide ranges of inputs must work for complex divide.
-   2 means C9X-like requirements for complex divide (not yet implemented).  */
+   2 means C99-like requirements for complex divide (not yet implemented).  */
 
 extern int flag_complex_divide_method;
 
index efd1055b9e21b24f6be7c68d95e8d9fca72cd1ed..c5b29a47242e407e7e14b7276064ababf620a15a 100644 (file)
@@ -1042,7 +1042,7 @@ fail:
   return 1;
 }
 
-/* Convert C9X hexadecimal floating point string constant S.  Return
+/* Convert C99 hexadecimal floating point string constant S.  Return
    real value type in mode MODE.  This function uses the host computer's
    floating point arithmetic when there is no REAL_ARITHMETIC.  */
 
index 6c09f753ce922f1f26e6eeac523b0c116ea563e1..9df904021562c509488bea8627802a2842e66da6 100644 (file)
@@ -5122,7 +5122,7 @@ asctoe (s, y)
 }
 
 /* Convert ASCII string SS to e type Y, with a specified rounding precision
-   of OPREC bits.  BASE is 16 for C9X hexadecimal floating constants.  */
+   of OPREC bits.  BASE is 16 for C99 hexadecimal floating constants.  */
 
 static void
 asctoeg (ss, y, oprec)
index e4b2c48ad337c2963c5d778c62f33637833c0b84..bb986e998b9cf8917d4398d4538f104692c12fd7 100644 (file)
--- a/gcc/rtl.c
+++ b/gcc/rtl.c
@@ -1093,7 +1093,7 @@ read_rtx (infile)
 #if HOST_BITS_PER_WIDE_INT == HOST_BITS_PER_LONG
        tmp_wide = atol (tmp_char);
 #else
/* Prefer atoll over atoq, since the former is in the ISO C9X draft.
           But prefer not to use our hand-rolled function above either.  */
 #if defined(HAVE_ATOLL) || !defined(HAVE_ATOQ)
        tmp_wide = atoll (tmp_char);
index f6a428820a29c506a30af3fa9b4eba7e1e31dd2c..4194b592afb6dfeae9c4e530f5a95fb03a9d0e50 100644 (file)
@@ -632,7 +632,7 @@ int flag_errno_math = 1;
 
 /* 0 means straightforward implementation of complex divide acceptable.
    1 means wide ranges of inputs must work for complex divide.
-   2 means C9X-like requirements for complex divide (not yet implemented).  */
+   2 means C99-like requirements for complex divide (not yet implemented).  */
 
 int flag_complex_divide_method = 0;
@@ -1093,7 +1093,7 @@ read_rtx (infile)
        tmp_wide = atol (tmp_char);
 #else
-       /* Prefer atoll over atoq, since the former is in the ISO C9X draft.
+       /* Prefer atoll over atoq, since the former is in the ISO C99 standard.
           But prefer not to use our hand-rolled function above either.  */
 #if defined(HAVE_ATOLL) || !defined(HAVE_ATOQ)